﻿using System;
using System.IO;
using System.Windows.Forms;
using KellermanSoftware.NetPgpLibrary;

namespace NET_PGP_Demo
{
    public partial class frmMain : Form
    {
        private string _defaultDirectory;
        public frmMain()
        {
            InitializeComponent();
            Setup();
        }

        private void Setup()
        {
            SetDefaultDirectory();
            EnableDisableControls();
        }

        private void EnableDisableControls()
        {
            btnGenerate.Enabled = txtUserName.Text.Length > 0
                && txtPassword.Text.Length > 0;

            grpFiles.Enabled = btnGenerate.Enabled
                && File.Exists(lblPublicKeyPath.Text)
                && File.Exists(lblPrivateKeyPath.Text);

            btnEncrypt.Enabled = grpFiles.Enabled
                && File.Exists(lblOriginalFilePath.Text);

            btnDecrypt.Enabled = grpFiles.Enabled
                                 && File.Exists(lblEncryptedFilePath.Text);

            if (!btnDecrypt.Enabled)
                lblDecryptedFilePath.Text = string.Empty;


        }

        private void HandleError(Exception ex)
        {
            MessageBox.Show(ex.ToString(), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }

        private void SetDefaultDirectory()
        {
            try
            {
                _defaultDirectory = Path.Combine(Path.Combine(Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData)
                    , "KellermanSoftware"), "NetPgpDemo");

                if (!Directory.Exists(_defaultDirectory))
                    Directory.CreateDirectory(_defaultDirectory);
            }
            catch (Exception exception)
            {
                HandleError(exception);
            }                
        }

        private void btnGenerate_Click(object sender, EventArgs e)
        {
            try
            {
                PgpEncryptorDecryptor pgpEncryptorDecryptor = new PgpEncryptorDecryptor(); //Trial Mode
                //PgpEncryptorDecryptor pgpEncryptorDecryptor = new PgpEncryptorDecryptor("place user name here", "place license key here"); //License Mode

                string publicKeyFilePath = Path.Combine(_defaultDirectory, "public.asc");
                string privateKeyFilePath = Path.Combine(_defaultDirectory, "private.asc");

                pgpEncryptorDecryptor.GenerateKeyPairFiles(txtUserName.Text, txtPassword.Text, publicKeyFilePath, privateKeyFilePath);

                lblPublicKeyPath.Text = publicKeyFilePath;
                lblPrivateKeyPath.Text = privateKeyFilePath;

                EnableDisableControls();
            }
            catch (Exception exception)
            {
                HandleError(exception);
            }
        }

        private void btnPublicKey_Click(object sender, EventArgs e)
        {
            if (fileDialog.ShowDialog(this) == DialogResult.OK)
            {
                lblPublicKeyPath.Text = fileDialog.FileName;
                EnableDisableControls();
            }
        }

        private void btnPrivateKey_Click(object sender, EventArgs e)
        {
            if (fileDialog.ShowDialog(this) == DialogResult.OK)
            {
                lblPrivateKeyPath.Text = fileDialog.FileName;
                EnableDisableControls();
            }
        }

        private void btnOriginalFile_Click(object sender, EventArgs e)
        {
            if (fileDialog.ShowDialog(this) == DialogResult.OK)
            {
                lblOriginalFilePath.Text = fileDialog.FileName;
                EnableDisableControls();
            }
        }

        private void btnEncryptedFile_Click(object sender, EventArgs e)
        {
            if (fileDialog.ShowDialog(this) == DialogResult.OK)
            {
                lblEncryptedFilePath.Text = fileDialog.FileName;
                EnableDisableControls();
            }
        }

        private void btnEncrypt_Click(object sender, EventArgs e)
        {
            try
            {
                PgpEncryptorDecryptor pgpEncryptorDecryptor = new PgpEncryptorDecryptor(); //Trial Mode
                //PgpEncryptorDecryptor pgpEncryptorDecryptor = new PgpEncryptorDecryptor("place user name here", "place license key here"); //License Mode

                string encryptedFilePath = Path.Combine(Path.GetDirectoryName(lblOriginalFilePath.Text), 
                    Path.GetFileNameWithoutExtension(lblOriginalFilePath.Text) + ".pgp");

                bool armor = false;

                pgpEncryptorDecryptor.EncryptFile(lblOriginalFilePath.Text, encryptedFilePath, lblPublicKeyPath.Text, armor);

                lblEncryptedFilePath.Text = encryptedFilePath;
                EnableDisableControls();
            }
            catch (Exception exception)
            {
                HandleError(exception);
            }

        }

        private void btnDecrypt_Click(object sender, EventArgs e)
        {
            try
            {
                PgpEncryptorDecryptor pgpEncryptorDecryptor = new PgpEncryptorDecryptor(); //Trial Mode
                //PgpEncryptorDecryptor pgpEncryptorDecryptor = new PgpEncryptorDecryptor("place user name here", "place license key here"); //License Mode

                string decryptedFilePath = Path.Combine(Path.GetDirectoryName(lblEncryptedFilePath.Text),
                    Path.GetFileNameWithoutExtension(lblEncryptedFilePath.Text) + "_decrypted" + 
                    Path.GetExtension(lblOriginalFilePath.Text));

                pgpEncryptorDecryptor.DecryptFile(lblEncryptedFilePath.Text, decryptedFilePath, lblPrivateKeyPath.Text,
                    txtPassword.Text);

                lblDecryptedFilePath.Text = decryptedFilePath;
                EnableDisableControls();
            }
            catch (Exception exception)
            {
                HandleError(exception);
            }
        }
    }
}
